PolyLineEsri class

Constructors

PolyLineEsri({required List<LatLng> points, Color color = const Color(0xFF00FF00), double borderStrokeWidth = 0.0, Color borderColor = const Color(0xFFFFFF00), bool isDotted = false, dynamic attributes})

Properties

attributes → dynamic
final
borderColor → Color
final
borderStrokeWidth → double
final
boundingBox ↔ LatLngBounds
latefinal
color → Color
final
colorsStop → List<double>?
finalinherited
gradientColors → List<Color>?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
isDotted → bool
final
offsets → List<Offset>
final
points → List<LatLng>
final
renderHashCode → int
Used to batch draw calls to the canvas.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strokeCap → StrokeCap
finalinherited
strokeJoin → StrokeJoin
finalinherited
strokeWidth → double
finalinherited
useStrokeWidthInMeter → bool
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited